==> owntone-28.4.tar.xz: owntone-28.4/src/parsers/rsp_parser.h <==
/* A Bison parser, made by GNU Bison 3.5.1.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Undocumented macros, especially those whose name start with YY_,
   are private implementation details.  Do not rely on them.  */

#ifndef YY_RSP_PARSERS_RSP_PARSER_H_INCLUDED
# define YY_RSP_PARSERS_RSP_PARSER_H_INCLUDED
/* Debug traces.  */
#ifndef RSP_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define RSP_DEBUG 1
#  else
#   define RSP_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define RSP_DEBUG 1
# endif /* ! defined YYDEBUG */
#endif  /* ! defined RSP_DEBUG */
#if RSP_DEBUG
extern int rsp_debug;
#endif
/* "%code requires" blocks.  */
#line 194 "parsers/rsp_parser.y"

struct rsp_result {
  char str[1024];
  int offset;
  int err;
  char errmsg[128];
};

#line 65 "parsers/rsp_parser.h"

/* Token type.  */
#ifndef RSP_TOKENTYPE
# define RSP_TOKENTYPE
  enum rsp_tokentype
  {
    RSP_T_STRING = 258,
    RSP_T_NUM = 259,
    RSP_T_STRTAG = 260,
    RSP_T_INTTAG = 261,
    RSP_T_PARENS = 262,
    RSP_T_OR = 263,
    RSP_T_AND = 264,
    RSP_T_NOT = 265,
    RSP_T_EQUAL = 266,
    RSP_T_IS = 267,
    RSP_T_INCLUDES = 268
  };
#endif

/* Value type.  */
#if ! defined RSP_STYPE && ! defined RSP_STYPE_IS_DECLARED
union RSP_STYPE
{
#line 368 "parsers/rsp_parser.y"

  unsigned int ival;
  char *str;
  struct ast *ast;

#line 96 "parsers/rsp_parser.h"

};
typedef union RSP_STYPE RSP_STYPE;
# define RSP_STYPE_IS_TRIVIAL 1
# define RSP_STYPE_IS_DECLARED 1
#endif



int rsp_parse (struct rsp_result *result, void *scanner);
/* "%code provides" blocks.  */
#line 42 "parsers/rsp_parser.y"

/* Convenience functions for caller to use instead of interfacing with lexer and
   parser directly */
int rsp_lex_cb(char *input, void (*cb)(int, const char *));
int rsp_lex_parse(struct rsp_result *result, const char *input);

#line 115 "parsers/rsp_parser.h"

#endif /* !YY_RSP_PARSERS_RSP_PARSER_H_INCLUDED  */

==> owntone-29.0.tar.xz: owntone-29.0/src/parsers/rsp_parser.h <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_RSP_PARSERS_RSP_PARSER_H_INCLUDED
# define YY_RSP_PARSERS_RSP_PARSER_H_INCLUDED
/* Debug traces.  */
#ifndef RSP_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define RSP_DEBUG 1
#  else
#   define RSP_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define RSP_DEBUG 1
# endif /* ! defined YYDEBUG */
#endif  /* ! defined RSP_DEBUG */
#if RSP_DEBUG
extern int rsp_debug;
#endif
/* "%code requires" blocks.  */
#line 195 "parsers/rsp_parser.y"

struct rsp_result {
  char str[1024];
  int offset;
  int err;
  char errmsg[128];

  int recursion_level;
};

#line 68 "parsers/rsp_parser.h"

/* Token kinds.  */
#ifndef RSP_TOKENTYPE
# define RSP_TOKENTYPE
  enum rsp_tokentype
  {
    RSP_EMPTY = -2,
    RSP_EOF = 0,                   /* "end of file"  */
    RSP_error = 256,               /* error  */
    RSP_UNDEF = 257,               /* "invalid token"  */
    RSP_T_STRING = 258,            /* RSP_T_STRING  */
    RSP_T_NUM = 259,               /* RSP_T_NUM  */
    RSP_T_STRTAG = 260,            /* RSP_T_STRTAG  */
    RSP_T_INTTAG = 261,            /* RSP_T_INTTAG  */
    RSP_T_PARENS = 262,            /* RSP_T_PARENS  */
    RSP_T_OR = 263,                /* RSP_T_OR  */
    RSP_T_AND = 264,               /* RSP_T_AND  */
    RSP_T_NOT = 265,               /* RSP_T_NOT  */
    RSP_T_EQUAL = 266,             /* RSP_T_EQUAL  */
    RSP_T_IS = 267,                /* RSP_T_IS  */
    RSP_T_INCLUDES = 268           /* RSP_T_INCLUDES  */
  };
  typedef enum rsp_tokentype rsp_token_kind_t;
#endif

/* Value type.  */
#if ! defined RSP_STYPE && ! defined RSP_STYPE_IS_DECLARED
union RSP_STYPE
{
#line 382 "parsers/rsp_parser.y"

  unsigned int ival;
  char *str;
  struct ast *ast;

#line 104 "parsers/rsp_parser.h"

};
typedef union RSP_STYPE RSP_STYPE;
# define RSP_STYPE_IS_TRIVIAL 1
# define RSP_STYPE_IS_DECLARED 1
#endif




int rsp_parse (struct rsp_result *result, void *scanner);

/* "%code provides" blocks.  */
#line 42 "parsers/rsp_parser.y"

/* Convenience functions for caller to use instead of interfacing with lexer and
   parser directly */
int rsp_lex_cb(char *input, void (*cb)(int, const char *));
int rsp_lex_parse(struct rsp_result *result, const char *input);

#line 125 "parsers/rsp_parser.h"

#endif /* !YY_RSP_PARSERS_RSP_PARSER_H_INCLUDED  */
